<?php
/**
 * Web Developer Theme Customizer
 *
 * @package Web Developer
 */

get_template_part('/inc/select/category-dropdown-custom-control');

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function web_developer_customize_register( $wp_customize ) {

	function web_developer_sanitize_phone_number( $phone ) {
		return preg_replace( '/[^\d+]/', '', $phone );
	}

	function web_developer_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	}

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	//Theme Options
	$wp_customize->add_panel( 'web_developer_panel_area', array(
		'priority' => 10,
		'capability' => 'edit_theme_options',
		'title' => __( 'Theme Options Panel', 'web-developer' ),
	) );
	
	// Header Section
	$wp_customize->add_section('web_developer_header_section', array(
        'title' => __('Manage Header Section', 'web-developer'),
        'priority' => null,
		'panel' => 'web_developer_panel_area',
 	));

	$wp_customize->add_setting('web_developer_address_location_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'web_developer_address_location_text', array(
	   'settings' => 'web_developer_address_location_text',
	   'section'   => 'web_developer_header_section',
	   'label' => __('Add Text', 'web-developer'),
	   'type'      => 'text'
	));

	$wp_customize->add_setting('web_developer_address_location',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'web_developer_address_location', array(
	   'settings' => 'web_developer_address_location',
	   'section'   => 'web_developer_header_section',
	   'label' => __('Add Location Address', 'web-developer'),
	   'type'      => 'text'
	));

 	$wp_customize->add_setting('web_developer_email_address_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'web_developer_email_address_text', array(
	   'settings' => 'web_developer_email_address_text',
	   'section'   => 'web_developer_header_section',
	   'label' => __('Add Text', 'web-developer'),
	   'type'      => 'text'
	));

	$wp_customize->add_setting('web_developer_email_address',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_email',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'web_developer_email_address', array(
	   'settings' => 'web_developer_email_address',
	   'section'   => 'web_developer_header_section',
	   'label' => __('Add Email Address', 'web-developer'),
	   'type'      => 'text'
	));

	$wp_customize->add_setting('web_developer_phone_number_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'web_developer_phone_number_text', array(
	   'settings' => 'web_developer_phone_number_text',
	   'section'   => 'web_developer_header_section',
	   'label' => __('Add Text', 'web-developer'),
	   'type'      => 'text'
	));

	$wp_customize->add_setting('web_developer_phone_number',array(
		'default' => '',
		'sanitize_callback' => 'web_developer_sanitize_phone_number',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'web_developer_phone_number', array(
	   'settings' => 'web_developer_phone_number',
	   'section'   => 'web_developer_header_section',
	   'label' => __('Add Phone Number', 'web-developer'),
	   'type'      => 'text'
	));

	// Home Category Dropdown Section
	$wp_customize->add_section('web_developer_one_cols_section',array(
		'title'	=> __('Manage Slider','web-developer'),
		'description'	=> __('Select Category from the Dropdowns for slider, Also use the given image dimension (1600 x 850).','web-developer'),
		'priority'	=> null,
		'panel' => 'web_developer_panel_area'
	));

	// Add a category dropdown Slider Coloumn
	$wp_customize->add_setting( 'web_developer_slidersection', array(
		'default'	=> '0',	
		'sanitize_callback'	=> 'absint'
	) );
	$wp_customize->add_control( new Web_Developer_Category_Dropdown_Custom_Control( $wp_customize, 'web_developer_slidersection', array(
		'section' => 'web_developer_one_cols_section',
		'settings'   => 'web_developer_slidersection',
	) ) );

	$wp_customize->add_setting('web_developer_button_text',array(
		'default' => 'Hire Me',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'web_developer_button_text', array(
	   'settings' => 'web_developer_button_text',
	   'section'   => 'web_developer_one_cols_section',
	   'label' => __('Add Button Text', 'web-developer'),
	   'type'      => 'text'
	));
	
	//Hide Section
	$wp_customize->add_setting('web_developer_hide_categorysec',array(
		'default' => true,
		'sanitize_callback' => 'web_developer_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 

	$wp_customize->add_control( 'web_developer_hide_categorysec', array(
	   'settings' => 'web_developer_hide_categorysec',
	   'section'   => 'web_developer_one_cols_section',
	   'label'     => __('Uncheck To Enable This Section','web-developer'),
	   'type'      => 'checkbox'
	));
	
	// Services Section 
	$wp_customize->add_section('web_developer_below_slider_section', array(
		'title'	=> __('Manage Services Section','web-developer'),
		'description'	=> __('Select Pages from the dropdown for Services.','web-developer'),
		'priority'	=> null,
		'panel' => 'web_developer_panel_area',
	));

	$wp_customize->add_setting('web_developer_main_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'web_developer_main_text', array(
	   'settings' => 'web_developer_main_text',
	   'section'   => 'web_developer_below_slider_section',
	   'label' => __('Add Main Text', 'web-developer'),
	   'type'      => 'text'
	));
	
	$wp_customize->add_setting('web_developer_main_title',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'web_developer_main_title', array(
	   'settings' => 'web_developer_main_title',
	   'section'   => 'web_developer_below_slider_section',
	   'label' => __('Add Main Title', 'web-developer'),
	   'type'      => 'text'
	));

	// Add a category dropdown Slider Coloumn
	$wp_customize->add_setting( 'web_developer_services_cat', array(
		'default'	=> '0',	
		'sanitize_callback'	=> 'absint'
	) );
	$wp_customize->add_control( new Web_Developer_Category_Dropdown_Custom_Control( $wp_customize, 'web_developer_services_cat', array(
		'section' => 'web_developer_below_slider_section',
		'settings'   => 'web_developer_services_cat',
	) ) );

	$wp_customize->add_setting('web_developer_disabled_pgboxes',array(
		'default' => true,
		'sanitize_callback' => 'web_developer_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));
	
	$wp_customize->add_control( 'web_developer_disabled_pgboxes', array(
	   'settings' => 'web_developer_disabled_pgboxes',
	   'section'   => 'web_developer_below_slider_section',
	   'label'     => __('Uncheck To Enable This Section','web-developer'),
	   'type'      => 'checkbox'
	));

	// Footer Section 
	$wp_customize->add_section('web_developer_footer', array(
		'title'	=> __('Manage Footer Section','web-developer'),
		'priority'	=> null,
		'panel' => 'web_developer_panel_area',
	));

	$wp_customize->add_setting('web_developer_copyright_line',array(
		'sanitize_callback' => 'sanitize_text_field',
	));	
	$wp_customize->add_control( 'web_developer_copyright_line', array(
	   'section' 	=> 'web_developer_footer',
	   'label'	 	=> __('Copyright Line','web-developer'),
	   'type'    	=> 'text',
	   'priority' 	=> null,
    ));

	// Google Fonts
    $wp_customize->add_section( 'web_developer_google_fonts_section', array(
		'title'       => __( 'Google Fonts', 'web-developer' ),
		'priority'    => 24,
	) );

	$font_choices = array(
		'' => 'select',
		'Kaushan Script:' => 'Kaushan Script',
		'Emilys Candy:' => 'Emilys Candy',
		'Poppins:0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900' => 'Poppins',
		'Source Sans Pro:400,700,400italic,700italic' => 'Source Sans Pro',
		'Open Sans:400italic,700italic,400,700' => 'Open Sans',
		'Oswald:400,700' => 'Oswald',
		'Playfair Display:400,700,400italic' => 'Playfair Display',
		'Montserrat:400,700' => 'Montserrat',
		'Raleway:400,700' => 'Raleway',
		'Droid Sans:400,700' => 'Droid Sans',
		'Lato:400,700,400italic,700italic' => 'Lato',
		'Arvo:400,700,400italic,700italic' => 'Arvo',
		'Lora:400,700,400italic,700italic' => 'Lora',
		'Merriweather:400,300italic,300,400italic,700,700italic' => 'Merriweather',
		'Oxygen:400,300,700' => 'Oxygen',
		'PT Serif:400,700' => 'PT Serif',
		'PT Sans:400,700,400italic,700italic' => 'PT Sans',
		'PT Sans Narrow:400,700' => 'PT Sans Narrow',
		'Cabin:400,700,400italic' => 'Cabin',
		'Fjalla One:400' => 'Fjalla One',
		'Francois One:400' => 'Francois One',
		'Josefin Sans:400,300,600,700' => 'Josefin Sans',
		'Libre Baskerville:400,400italic,700' => 'Libre Baskerville',
		'Arimo:400,700,400italic,700italic' => 'Arimo',
		'Ubuntu:400,700,400italic,700italic' => 'Ubuntu',
		'Bitter:400,700,400italic' => 'Bitter',
		'Droid Serif:400,700,400italic,700italic' => 'Droid Serif',
		'Roboto:400,400italic,700,700italic' => 'Roboto',
		'Open Sans Condensed:700,300italic,300' => 'Open Sans Condensed',
		'Roboto Condensed:400italic,700italic,400,700' => 'Roboto Condensed',
		'Roboto Slab:400,700' => 'Roboto Slab',
		'Yanone Kaffeesatz:400,700' => 'Yanone Kaffeesatz',
		'Rokkitt:400' => 'Rokkitt',
	);

	$wp_customize->add_setting( 'web_developer_headings_fonts', array(
		'sanitize_callback' => 'web_developer_sanitize_fonts',
	));
	$wp_customize->add_control( 'web_developer_headings_fonts', array(
		'type' => 'select',
		'description' => __('Select your desired font for the headings.', 'web-developer'),
		'section' => 'web_developer_google_fonts_section',
		'choices' => $font_choices
	));

	$wp_customize->add_setting( 'web_developer_body_fonts', array(
		'sanitize_callback' => 'web_developer_sanitize_fonts'
	));
	$wp_customize->add_control( 'web_developer_body_fonts', array(
		'type' => 'select',
		'description' => __( 'Select your desired font for the body.', 'web-developer' ),
		'section' => 'web_developer_google_fonts_section',
		'choices' => $font_choices
	));
}
add_action( 'customize_register', 'web_developer_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function web_developer_customize_preview_js() {
	wp_enqueue_script( 'web_developer_customizer', esc_url(get_template_directory_uri()) . '/js/customize-preview.js', array( 'customize-preview' ), '20161510', true );
}
add_action( 'customize_preview_init', 'web_developer_customize_preview_js' );